LIBRARY
EXPORTS
icalcalendar_create
icalcalendar_free
icalcalendar_get_booked
icalcalendar_get_freebusy
icalcalendar_get_incoming
icalcalendar_get_properties
icalcalendar_islocked
icalcalendar_lock
icalcalendar_new
icalcalendar_new_impl
icalcalendar_ownlock
icalcalendar_unlock
icalclassify
icalclassify_add_instance
icalclassify_cancel_all
icalclassify_cancel_event
icalclassify_cancel_instance
icalclassify_counter
icalclassify_delinecounter
icalclassify_find_attendee
icalclassify_find_overlaps
icalclassify_lowercase
icalclassify_publish_freebusy
icalclassify_publish_new
icalclassify_publish_update
icalclassify_refesh
icalclassify_reply_accept
icalclassify_reply_crasher_accept
icalclassify_reply_crasher_decline
icalclassify_reply_decline
icalclassify_reply_delegate
icalclassify_request_delegate
icalclassify_request_forward
icalclassify_request_freebusy
icalclassify_request_new
icalclassify_request_new_organizer
icalclassify_request_reschedule
icalclassify_request_status
icalclassify_request_update
icalcluster_add_component
icalcluster_commit
icalcluster_count_components
icalcluster_free
icalcluster_get_component
icalcluster_get_current_component
icalcluster_get_first_component
icalcluster_get_next_component
icalcluster_is_changed
icalcluster_key
icalcluster_mark
icalcluster_new
icalcluster_new_clone
icalcluster_new_impl
icalcluster_remove_component
icaldirset_add_component
icaldirset_begin_component
icaldirset_clear
icaldirset_commit
icaldirset_count_components
icaldirset_fetch
icaldirset_fetch_match
icaldirset_free
icaldirset_get_current_component
icaldirset_get_first_component
icaldirset_get_next_component
icaldirset_has_uid
icaldirset_init
icaldirset_lock
icaldirset_mark
icaldirset_modify
icaldirset_new
icaldirset_new_reader
icaldirset_new_writer
icaldirset_next_cluster
icaldirset_next_uid_number
icaldirset_options_default DATA
icaldirset_path
icaldirset_read_directory
icaldirset_remove_component
icaldirset_select
icaldirset_unlock
icaldirsetiter_to_next
icaldirsetiter_to_prior
icalfileset_add_component
icalfileset_begin_component
icalfileset_clear
icalfileset_commit
icalfileset_count_components
icalfileset_fetch
icalfileset_fetch_match
icalfileset_filesize
icalfileset_form_a_matched_recurrence_component
icalfileset_free
icalfileset_get_component
icalfileset_get_current_component
icalfileset_get_first_component
icalfileset_get_id
icalfileset_get_next_component
icalfileset_has_uid
icalfileset_id_free
icalfileset_init
icalfileset_lock
icalfileset_mark
icalfileset_modify
icalfileset_new
icalfileset_new_reader
icalfileset_new_writer
icalfileset_options_default DATA
icalfileset_path
icalfileset_produce_icalcluster
icalfileset_read_file
icalfileset_read_from_file
icalfileset_remove_component
icalfileset_select
icalfileset_unlock
icalfilesetiter_to_next
icalgauge_compare
icalgauge_compare_recurse
icalgauge_dump
icalgauge_free
icalgauge_get_expand
icalgauge_new_from_sql
icalmessage_copy_properties
icalmessage_find_attendee
icalmessage_get_inner
icalmessage_new_accept_reply
icalmessage_new_counterpropose_reply
icalmessage_new_decline_reply
icalmessage_new_delegate_reply
icalmessage_new_delegate_request
icalmessage_new_error_reply
icalmessage_new_reply_base
icalset_add_component
icalset_begin_component
icalset_clear
icalset_commit
icalset_count_components
icalset_fetch
icalset_fetch_match
icalset_free
icalset_get_current_component
icalset_get_first_component
icalset_get_next_component
icalset_has_uid
icalset_mark
icalset_modify
icalset_new
icalset_new_dir
icalset_new_dir_reader
icalset_new_dir_writer
icalset_new_file
icalset_new_file_reader
icalset_new_file_writer
icalset_path
icalset_remove_component
icalset_select
icalsetiter_deref
icalsetiter_next
icalsetiter_null DATA
icalsetiter_prior
icalsetiter_to_next
icalsetiter_to_prior
icalspanlist_as_freebusy_matrix
icalspanlist_as_vfreebusy
icalspanlist_dump
icalspanlist_free
icalspanlist_from_vfreebusy
icalspanlist_new
icalspanlist_next_free_time
icalss_input
icalss_yy_gauge DATA
icalssutil_free_parts
icalssutil_get_parts
icalssutil_is_rescheduled
input_buffer DATA
input_buffer_p DATA
ss_create_buffer
ss_delete_buffer
ss_flush_buffer
ss_scan_buffer
ss_scan_bytes
ss_scan_string
ss_switch_to_buffer
sschar DATA
sserror
ssin DATA
ssleng DATA
sslex
sslval DATA
ssnerrs DATA
ssout DATA
ssparse
ssrestart
sstext DATA
sswrap
yytext_ptr DATA
